<?php
namespace Pinpoint\ScrollToTop\ViewModel;

class GetOptions implements \Magento\Framework\View\Element\Block\ArgumentInterface
{
    public function __construct(
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Store\Model\StoreManagerInterface $storeManager
    ) {
        $this->scopeConfig = $scopeConfig;
        $this->storeManager = $storeManager;
    }
       
    public function cmsEnabled():bool {
        return $this->scopeConfig->isSetFlag("scrolltotop/general/cms_page_enabled",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId());
    }

    public function plpEnabled():bool {
        return $this->scopeConfig->isSetFlag("scrolltotop/general/plp_enabled",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId());
    }

    public function pdpEnabled():bool {
        return $this->scopeConfig->isSetFlag("scrolltotop/general/pdp_enabled",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId());
    }

    public function getScrollDepth():int {
        return $this->scopeConfig->getValue("scrolltotop/general/scroll_depth",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? 500;
    }

    public function getScrollSpeed():int {
        return $this->scopeConfig->getValue("scrolltotop/general/scroll_speed",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? 500;
    }

    public function getBackgroundColor():string {
        return $this->scopeConfig->getValue("scrolltotop/display/background_color",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? "#000";
    }

    public function getForegroundColor():string {
        return $this->scopeConfig->getValue("scrolltotop/display/foreground_color",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? "#fff";
    }

    public function getRenderMode():string {
        return $this->scopeConfig->getValue("scrolltotop/display/render_mode",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? "icon";
    }

    public function getIconPosition():string {
        return $this->scopeConfig->getValue("scrolltotop/display/icon_position",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? "top";
    }
    
    public function getTextLabel():string {
        return $this->scopeConfig->getValue("scrolltotop/display/text_label",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? "Scroll to Top";
    }

    public function getBorderRadius():string {
        return $this->scopeConfig->getValue("scrolltotop/display/border_radius",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? 0;
    }

    public function getBorderWidth():string {
        return $this->scopeConfig->getValue("scrolltotop/display/border_width",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? 1;
    }

    public function getBorderColor():string {
        return $this->scopeConfig->getValue("scrolltotop/display/border_color",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? "#fff";
    }

    public function getZIndex():int {
        return $this->scopeConfig->getValue("scrolltotop/display/z_index",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? 1;
    }
}
